<a id="mypy-boto3-emr"></a>

# mypy-boto3-emr

[![PyPI - types-aiobotocore-emr](https://img.shields.io/pypi/v/types-aiobotocore-emr.svg?color=blue)](https://pypi.org/project/types-aiobotocore-emr)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-emr.svg?color=blue)](https://pypi.org/project/types-aiobotocore-emr)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-emr?color=blue)](https://pypistats.org/packages/types-aiobotocore-emr)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.EMR 1.20.47](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr.html#EMR)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.4.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[types-aiobotocore-emr docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_emr/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-emr](#mypy-boto3-emr)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `EMR`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `EMR` service.

```bash
python -m pip install types-aiobotocore[emr]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[emr]` in your environment:
  `python -m pip install 'types-aiobotocore[emr]'`

Both type checking and auto-complete should work for `EMR` service. No explicit
type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `types-aiobotocore[emr]` in your environment:
  `python -m pip install 'types-aiobotocore[emr]'`

Both type checking and auto-complete should work for `EMR` service. No explicit
type annotations required, write your `aiobotocore` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`types-aiobotocore` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[emr]` in your environment:
  `python -m pip install 'types-aiobotocore[emr]'`
- Run `mypy` as usual

Type checking should work for `EMR` service. No explicit type annotations
required, write your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `types-aiobotocore[emr]` in your environment:
  `python -m pip install 'types-aiobotocore[emr]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `EMR` service. No explicit type annotations
required, write your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`EMRClient` provides annotations for `session.create_client("emr")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_emr import EMRClient

session = get_session()
with async session.create_client("emr") as client:
    client: EMRClient
    # now client usage is checked by mypy and IDE should provide code auto-complete
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_emr.paginator` module contains type annotations for all
paginators.

````python
from aiobotocore.session import get_session

from types_aiobotocore_emr import EMRClient
from types_aiobotocore_emr.paginator import (
    ListBootstrapActionsPaginator,
    ListClustersPaginator,
    ListInstanceFleetsPaginator,
    ListInstanceGroupsPaginator,
    ListInstancesPaginator,
    ListNotebookExecutionsPaginator,
    ListSecurityConfigurationsPaginator,
    ListStepsPaginator,
    ListStudioSessionMappingsPaginator,
    ListStudiosPaginator,
)

session = get_session()
with async session.create_client("emr") as client:
    client: EMRClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        list_bootstrap_actions_paginator: ListBootstrapActionsPaginator = client.get_paginator("list_bootstrap_actions")
        list_clusters_paginator: ListClustersPaginator = client.get_paginator("list_clusters")
        list_instance_fleets_paginator: ListInstanceFleetsPaginator = client.get_paginator("list_instance_fleets")
        list_instance_groups_paginator: ListInstanceGroupsPaginator = client.get_paginator("list_instance_groups")
        list_instances_paginator: ListInstancesPaginator = client.get_paginator("list_instances")
        list_notebook_executions_paginator: ListNotebookExecutionsPaginator = client.get_paginator("list_notebook_executions")
        list_security_configurations_paginator: ListSecurityConfigurationsPaginator = client.get_paginator("list_security_configurations")
        list_steps_paginator: ListStepsPaginator = client.get_paginator("list_steps")
        list_studio_session_mappings_paginator: ListStudioSessionMappingsPaginator = client.get_paginator("list_studio_session_mappings")
        list_studios_paginator: ListStudiosPaginator = client.get_paginator("list_studios")
    ```


### Waiters annotations

`types_aiobotocore_emr.waiter` module contains type annotations for all waiters.

```python
from aiobotocore.session import get_session

from types_aiobotocore_emr.client import EMRClient
from types_aiobotocore_emr.waiter import (
    ClusterRunningWaiter,
    ClusterTerminatedWaiter,
    StepCompleteWaiter,
)

session = get_session()
with async session.create_client("emr") as client:
    client: EMRClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        cluster_running_waiter: ClusterRunningWaiter = client.get_waiter("cluster_running")
        cluster_terminated_waiter: ClusterTerminatedWaiter = client.get_waiter("cluster_terminated")
        step_complete_waiter: StepCompleteWaiter = client.get_waiter("step_complete")
    ```





<a id="literals"></a>

### Literals

`types_aiobotocore_emr.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from types_aiobotocore_emr.literals import (
    ActionOnFailureType,
    AdjustmentTypeType,
    AuthModeType,
    AutoScalingPolicyStateChangeReasonCodeType,
    AutoScalingPolicyStateType,
    CancelStepsRequestStatusType,
    ClusterRunningWaiterName,
    ClusterStateChangeReasonCodeType,
    ClusterStateType,
    ClusterTerminatedWaiterName,
    ComparisonOperatorType,
    ComputeLimitsUnitTypeType,
    ExecutionEngineTypeType,
    IdentityTypeType,
    InstanceCollectionTypeType,
    InstanceFleetStateChangeReasonCodeType,
    InstanceFleetStateType,
    InstanceFleetTypeType,
    InstanceGroupStateChangeReasonCodeType,
    InstanceGroupStateType,
    InstanceGroupTypeType,
    InstanceRoleTypeType,
    InstanceStateChangeReasonCodeType,
    InstanceStateType,
    JobFlowExecutionStateType,
    ListBootstrapActionsPaginatorName,
    ListClustersPaginatorName,
    ListInstanceFleetsPaginatorName,
    ListInstanceGroupsPaginatorName,
    ListInstancesPaginatorName,
    ListNotebookExecutionsPaginatorName,
    ListSecurityConfigurationsPaginatorName,
    ListStepsPaginatorName,
    ListStudioSessionMappingsPaginatorName,
    ListStudiosPaginatorName,
    MarketTypeType,
    NotebookExecutionStatusType,
    OnDemandCapacityReservationPreferenceType,
    OnDemandCapacityReservationUsageStrategyType,
    OnDemandProvisioningAllocationStrategyType,
    PlacementGroupStrategyType,
    RepoUpgradeOnBootType,
    ScaleDownBehaviorType,
    SpotProvisioningAllocationStrategyType,
    SpotProvisioningTimeoutActionType,
    StatisticType,
    StepCancellationOptionType,
    StepCompleteWaiterName,
    StepExecutionStateType,
    StepStateChangeReasonCodeType,
    StepStateType,
    UnitType,
    ServiceName,
    PaginatorName,
    WaiterName,
)

def check_value(value: ActionOnFailureType) -> bool:
    ...
````

<a id="typed-dictionaries"></a>

### Typed dictionaries

`types_aiobotocore_emr.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_emr.type_defs import (
    AddInstanceFleetInputRequestTypeDef,
    AddInstanceFleetOutputTypeDef,
    AddInstanceGroupsInputRequestTypeDef,
    AddInstanceGroupsOutputTypeDef,
    AddJobFlowStepsInputRequestTypeDef,
    AddJobFlowStepsOutputTypeDef,
    AddTagsInputRequestTypeDef,
    ApplicationTypeDef,
    AutoScalingPolicyDescriptionTypeDef,
    AutoScalingPolicyStateChangeReasonTypeDef,
    AutoScalingPolicyStatusTypeDef,
    AutoScalingPolicyTypeDef,
    AutoTerminationPolicyTypeDef,
    BlockPublicAccessConfigurationMetadataTypeDef,
    BlockPublicAccessConfigurationTypeDef,
    BootstrapActionConfigTypeDef,
    BootstrapActionDetailTypeDef,
    CancelStepsInfoTypeDef,
    CancelStepsInputRequestTypeDef,
    CancelStepsOutputTypeDef,
    CloudWatchAlarmDefinitionTypeDef,
    ClusterStateChangeReasonTypeDef,
    ClusterStatusTypeDef,
    ClusterSummaryTypeDef,
    ClusterTimelineTypeDef,
    ClusterTypeDef,
    CommandTypeDef,
    ComputeLimitsTypeDef,
    ConfigurationTypeDef,
    CreateSecurityConfigurationInputRequestTypeDef,
    CreateSecurityConfigurationOutputTypeDef,
    CreateStudioInputRequestTypeDef,
    CreateStudioOutputTypeDef,
    CreateStudioSessionMappingInputRequestTypeDef,
    DeleteSecurityConfigurationInputRequestTypeDef,
    DeleteStudioInputRequestTypeDef,
    DeleteStudioSessionMappingInputRequestTypeDef,
    DescribeClusterInputRequestTypeDef,
    DescribeClusterOutputTypeDef,
    DescribeJobFlowsInputRequestTypeDef,
    DescribeJobFlowsOutputTypeDef,
    DescribeNotebookExecutionInputRequestTypeDef,
    DescribeNotebookExecutionOutputTypeDef,
    DescribeReleaseLabelInputRequestTypeDef,
    DescribeReleaseLabelOutputTypeDef,
    DescribeSecurityConfigurationInputRequestTypeDef,
    DescribeSecurityConfigurationOutputTypeDef,
    DescribeStepInputRequestTypeDef,
    DescribeStepOutputTypeDef,
    DescribeStudioInputRequestTypeDef,
    DescribeStudioOutputTypeDef,
    EbsBlockDeviceConfigTypeDef,
    EbsBlockDeviceTypeDef,
    EbsConfigurationTypeDef,
    EbsVolumeTypeDef,
    Ec2InstanceAttributesTypeDef,
    ExecutionEngineConfigTypeDef,
    FailureDetailsTypeDef,
    GetAutoTerminationPolicyInputRequestTypeDef,
    GetAutoTerminationPolicyOutputTypeDef,
    GetBlockPublicAccessConfigurationOutputTypeDef,
    GetManagedScalingPolicyInputRequestTypeDef,
    GetManagedScalingPolicyOutputTypeDef,
    GetStudioSessionMappingInputRequestTypeDef,
    GetStudioSessionMappingOutputTypeDef,
    HadoopJarStepConfigTypeDef,
    HadoopStepConfigTypeDef,
    InstanceFleetConfigTypeDef,
    InstanceFleetModifyConfigTypeDef,
    InstanceFleetProvisioningSpecificationsTypeDef,
    InstanceFleetStateChangeReasonTypeDef,
    InstanceFleetStatusTypeDef,
    InstanceFleetTimelineTypeDef,
    InstanceFleetTypeDef,
    InstanceGroupConfigTypeDef,
    InstanceGroupDetailTypeDef,
    InstanceGroupModifyConfigTypeDef,
    InstanceGroupStateChangeReasonTypeDef,
    InstanceGroupStatusTypeDef,
    InstanceGroupTimelineTypeDef,
    InstanceGroupTypeDef,
    InstanceResizePolicyTypeDef,
    InstanceStateChangeReasonTypeDef,
    InstanceStatusTypeDef,
    InstanceTimelineTypeDef,
    InstanceTypeConfigTypeDef,
    InstanceTypeDef,
    InstanceTypeSpecificationTypeDef,
    JobFlowDetailTypeDef,
    JobFlowExecutionStatusDetailTypeDef,
    JobFlowInstancesConfigTypeDef,
    JobFlowInstancesDetailTypeDef,
    KerberosAttributesTypeDef,
    KeyValueTypeDef,
    ListBootstrapActionsInputRequestTypeDef,
    ListBootstrapActionsOutputTypeDef,
    ListClustersInputRequestTypeDef,
    ListClustersOutputTypeDef,
    ListInstanceFleetsInputRequestTypeDef,
    ListInstanceFleetsOutputTypeDef,
    ListInstanceGroupsInputRequestTypeDef,
    ListInstanceGroupsOutputTypeDef,
    ListInstancesInputRequestTypeDef,
    ListInstancesOutputTypeDef,
    ListNotebookExecutionsInputRequestTypeDef,
    ListNotebookExecutionsOutputTypeDef,
    ListReleaseLabelsInputRequestTypeDef,
    ListReleaseLabelsOutputTypeDef,
    ListSecurityConfigurationsInputRequestTypeDef,
    ListSecurityConfigurationsOutputTypeDef,
    ListStepsInputRequestTypeDef,
    ListStepsOutputTypeDef,
    ListStudioSessionMappingsInputRequestTypeDef,
    ListStudioSessionMappingsOutputTypeDef,
    ListStudiosInputRequestTypeDef,
    ListStudiosOutputTypeDef,
    ManagedScalingPolicyTypeDef,
    MetricDimensionTypeDef,
    ModifyClusterInputRequestTypeDef,
    ModifyClusterOutputTypeDef,
    ModifyInstanceFleetInputRequestTypeDef,
    ModifyInstanceGroupsInputRequestTypeDef,
    NotebookExecutionSummaryTypeDef,
    NotebookExecutionTypeDef,
    OnDemandCapacityReservationOptionsTypeDef,
    OnDemandProvisioningSpecificationTypeDef,
    PaginatorConfigTypeDef,
    PlacementGroupConfigTypeDef,
    PlacementTypeTypeDef,
    PortRangeTypeDef,
    PutAutoScalingPolicyInputRequestTypeDef,
    PutAutoScalingPolicyOutputTypeDef,
    PutAutoTerminationPolicyInputRequestTypeDef,
    PutBlockPublicAccessConfigurationInputRequestTypeDef,
    PutManagedScalingPolicyInputRequestTypeDef,
    ReleaseLabelFilterTypeDef,
    RemoveAutoScalingPolicyInputRequestTypeDef,
    RemoveAutoTerminationPolicyInputRequestTypeDef,
    RemoveManagedScalingPolicyInputRequestTypeDef,
    RemoveTagsInputRequestTypeDef,
    ResponseMetadataTypeDef,
    RunJobFlowInputRequestTypeDef,
    RunJobFlowOutputTypeDef,
    ScalingActionTypeDef,
    ScalingConstraintsTypeDef,
    ScalingRuleTypeDef,
    ScalingTriggerTypeDef,
    ScriptBootstrapActionConfigTypeDef,
    SecurityConfigurationSummaryTypeDef,
    SessionMappingDetailTypeDef,
    SessionMappingSummaryTypeDef,
    SetTerminationProtectionInputRequestTypeDef,
    SetVisibleToAllUsersInputRequestTypeDef,
    ShrinkPolicyTypeDef,
    SimpleScalingPolicyConfigurationTypeDef,
    SimplifiedApplicationTypeDef,
    SpotProvisioningSpecificationTypeDef,
    StartNotebookExecutionInputRequestTypeDef,
    StartNotebookExecutionOutputTypeDef,
    StepConfigTypeDef,
    StepDetailTypeDef,
    StepExecutionStatusDetailTypeDef,
    StepStateChangeReasonTypeDef,
    StepStatusTypeDef,
    StepSummaryTypeDef,
    StepTimelineTypeDef,
    StepTypeDef,
    StopNotebookExecutionInputRequestTypeDef,
    StudioSummaryTypeDef,
    StudioTypeDef,
    SupportedProductConfigTypeDef,
    TagTypeDef,
    TerminateJobFlowsInputRequestTypeDef,
    UpdateStudioInputRequestTypeDef,
    UpdateStudioSessionMappingInputRequestTypeDef,
    VolumeSpecificationTypeDef,
    WaiterConfigTypeDef,
)

def get_structure() -> AddInstanceFleetInputRequestTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`types-aiobotocore-emr` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[types-aiobotocore-emr docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_emr/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
